@@ -1,5 +1,5 @@
 /* meta.c	Implementation of function selection depending on mechanism.
- * Copyright (C) 2003  Simon Josefsson
+ * Copyright (C) 2003, 2004  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -22,7 +22,8 @@
 #include "internal.h"
 
 #ifdef USE_KERBEROS5
-#include "krb5.h"
+# include "krb5/krb5.h"
+# include "krb5/protos.h"
 #endif
 
 OM_uint32
@@ -40,45 +41,50 @@ _gss_dummy_display_status (OM_uint32 * minor_status,
 			   OM_uint32 * message_context,
 			   gss_buffer_t status_string)
 {
-  status_string->value = xstrdup(_("No suitable mechanism supported"));
-  status_string->length = strlen(status_string->value);
+  status_string->value = xstrdup (_("No suitable mechanism supported"));
+  status_string->length = strlen (status_string->value);
   return GSS_S_COMPLETE;
 }
 
 _gss_mech_api_desc _gss_mech_apis[] = {
 #ifdef USE_KERBEROS5
   {
-    &GSS_KRB5_static,
-    { &GSS_KRB5_NT_USER_NAME_static,
-      &GSS_C_NT_HOSTBASED_SERVICE_static,
-      &GSS_KRB5_NT_PRINCIPAL_NAME_static,
-      &GSS_KRB5_NT_STRING_UID_NAME_static },
-    gss_krb5_init_sec_context,
-    gss_krb5_canonicalize_name,
-    gss_krb5_wrap,
-    gss_krb5_unwrap,
-    _gss_dummy,
-    _gss_dummy,
-    gss_krb5_display_status,
-    gss_krb5_acquire_cred,
-    gss_krb5_accept_sec_context,
-    gss_krb5_inquire_cred
-  },
+   &GSS_KRB5_static,
+   {&GSS_KRB5_NT_USER_NAME_static,
+    &GSS_C_NT_HOSTBASED_SERVICE_static,
+    &GSS_KRB5_NT_PRINCIPAL_NAME_static,
+    &GSS_KRB5_NT_STRING_UID_NAME_static}
+   ,
+   gss_krb5_init_sec_context,
+   gss_krb5_canonicalize_name,
+   gss_krb5_wrap,
+   gss_krb5_unwrap,
+   _gss_dummy,
+   _gss_dummy,
+   gss_krb5_display_status,
+   gss_krb5_acquire_cred,
+   gss_krb5_accept_sec_context,
+   gss_krb5_delete_sec_context,
+   gss_krb5_context_time,
+   gss_krb5_inquire_cred}
+  ,
 #endif
   {
-    0,
-    { GSS_C_NO_OID },
-    _gss_dummy,
-    _gss_dummy,
-    _gss_dummy,
-    _gss_dummy,
-    _gss_dummy,
-    _gss_dummy,
-    _gss_dummy_display_status,
-    _gss_dummy,
-    _gss_dummy,
-    _gss_dummy
-  }
+   0,
+   {GSS_C_NO_OID}
+   ,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy_display_status,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy,
+   _gss_dummy}
 };
 
 _gss_mech_api_t
@@ -87,9 +93,8 @@ _gss_find_mech (gss_OID oid)
   int i;
   if (oid == GSS_C_NO_OID)
     return &_gss_mech_apis[0];
-  for (i = 0; i < sizeof(_gss_mech_apis) / sizeof(_gss_mech_apis[0]); i++)
+  for (i = 0; i < sizeof (_gss_mech_apis) / sizeof (_gss_mech_apis[0]); i++)
     if (gss_oid_equal (oid, _gss_mech_apis[i].mech))
       return &_gss_mech_apis[i];
-  return &_gss_mech_apis[i-1];
+  return &_gss_mech_apis[i - 1];
 }
-
